require 'fastcst/ui'
require 'fastcst/repo'
require 'fastcst/metadata'


module Repository

    class BeginCommand < Command
        def initialize(argv)
            @directory = "."
        
            super(argv, [
                ["-p", "--purpose TEXT", "The purpose of this revision", :@purpose],
                ["-r", "--revision NAME", "A name for the revision (make sure it can be a file name)", :@revision]
            ])
            
            @repo_dir = Repository.search
        end
    
        def validate
            valid? @repo_dir, "Could not find a repository directory"
            
            if @repo_dir
                @repo = Repository.new @repo_dir
                valid? @repo['Current Revision']==nil, "You are already working on revision #{@repo['Current Revision']}."
            end
            
            valid? @purpose, "You need to specify a purpose for this revision"
            valid? @revision, "No revision name given. (make sure it can be a file name)"

            return @valid
        end
    
    
        def run
            md_file = MetaData::META_DATA_FILE
            user = @repo['Created By']
            md = nil
            
            Dir.chdir @repo.work_dir do
                # create the initial meta-data
                MetaData.create_metadata(md_file, @repo['Project'], @revision, @purpose, user['Name'], user['E-Mail'])
                
                md = MetaData.load_metadata(md_file)
            end
            
            # now setup our information to indicate that we're currently working on this revision
            @repo['Current Revision'] = md['ID']
        end
    
    end
end

